==> mgug4121a_1.8.4.tar.gz: mgug4121a/man/mgug4121aGO.Rd <==
\name{mgug4121aGO}
\alias{mgug4121aGO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  mgug4121aGO is an R environment that provides mappings between
  manufacturer ids and GO ids.
}
\details{
  Each manufacturer id is mapped to a named vector of GO ids. The name
  associated with each GO id corresponds to the evidence code for that
  GO id. Evidence codes currently in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to Entrez Gene ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 16:28:52 2005

  Gene Ontology:\url{http://gopher5/compbio/annotationSourceData/www.godatabase.org/dev/database/archive/latest//go_200504-termdb.rdf-xml.gz}. Built: 200504
  
  Package built Tue May 17 16:43:24 2005
}

\examples{
    # Convert to a list
    xx <- as.list(mgug4121aGO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}

==> mgug4121a_1.10.0.tar.gz: mgug4121a/man/mgug4121aGO.Rd <==
\name{mgug4121aGO}
\alias{mgug4121aGO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  mgug4121aGO is an R environment that provides mappings between
  manufacturer ids and GO ids.
}
\details{
  Each manufacturer id is mapped to a named vector of GO ids. The name
  associated with each GO id corresponds to the evidence code for that
  GO id. Evidence codes currently in use include:
  
  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator
  
  Mappings between probe ids and GO information were obtained through
  their mappings to Entrez Gene ids. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology ids an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 22:45:42 2005

  Gene Ontology:\url{http://gopher5/compbio/annotationSourceData/archive.godatabase.org/latest//go_200509-termdb.rdf-xml.gz}. Built: 200509
  
  Package built Tue Oct  4 23:02:04 2005
}

\examples{
    # Convert to a list
    xx <- as.list(mgug4121aGO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}
